OC.L10N.register(
    "contacts",
    {
    "Contacts" : "אנשי קשר",
    "Download" : "הורדה",
    "Share with users or groups" : "שיתוף עם משתמשים או קבוצות",
    "Delete" : "מחיקה",
    "can edit" : "ניתן לערוך",
    "Address book name" : "שם ספר כתובות",
    "Import" : "יבוא",
    "The selected image is too big (max 1MB)" : "התמונה הנבחרת גדולה מדי (מקסימום 1 מגה בייט)",
    "No contacts in here" : "אין כאן אנשי קשר",
    "Name" : "שם",
    "Organization" : "ארגון",
    "Title" : "כותרת",
    "Add field ..." : "הוספת שדה...",
    "No search result for {query}" : "אין תוצאות חיפוש עבור {query}",
    "_%n contact_::_%n contacts_" : ["%n איש קשר","%n אנשי קשר"],
    "Post office box" : "תיבת דואר",
    "Postal code" : "מיקוד",
    "City" : "עיר",
    "State or province" : "מדינה או מחוז",
    "Country" : "מדינה",
    "Address" : "כתובת",
    "(new group)" : "(קבוצה חדשה)",
    "Last name" : "שם משפחה",
    "First name" : "שם פרטי",
    "Additional names" : "שמות נוספים",
    "Prefix" : "תואר",
    "Suffix" : "סיומת",
    "All contacts" : "כל אנשי הקשר",
    "Not grouped" : "לא שויך לקבוצה",
    "New contact" : "איש קשר חדש",
    "{addressbook} shared by {owner}" : "{addressbook} שותף על ידי {owner}",
    "Contact could not be created." : "לא ניתן היה ליצור איש קשר.",
    "No contacts in file. Only VCard files are allowed." : "אין אנשי קשר בקובץ. רק קובצי VCard ניתנים לשימוש.",
    "Nickname" : "כינוי",
    "Detailed name" : "פרטי שם",
    "Notes" : "הערות",
    "Website" : "אתר אינטרנט",
    "Federated Cloud ID" : "מספר זיהוי ענן מאוגד",
    "Home" : "בית",
    "Work" : "עבודה",
    "Other" : "אחר",
    "Groups" : "קבוצות",
    "Birthday" : "יום הולדת",
    "Anniversary" : "יום השנה",
    "Date of death" : "תאריך פטירה",
    "Email" : "דואר אלקטרוני",
    "Instant messaging" : "מסרים מיידיים",
    "Phone" : "טלפון",
    "Mobile" : "נייד",
    "Fax" : "פקס",
    "Fax home" : "פקס בבית",
    "Fax work" : "פקס בעבודה",
    "Pager" : "זימונית",
    "Voice" : "קולי",
    "Social network" : "רשת חברתית",
    "Settings" : "הגדרות"
},
"nplurals=2; plural=(n != 1);");
